@@ -12,7 +12,7 @@
 #'  regression analysis if treatments are quantitative. To compare the
 #'  additional control with the others treatments, the Dunnet test is used. This
 #'  function considers the randomized block design."
-#'@usage dbc.ad(Dados,alfa=0.05,quali=TRUE,verbose=TRUE)
+#'@usage dbc.ad(Dados,alfa=0.05,quali=TRUE,verbose=TRUE,plot=2)
 #'@param  Dados Matriz contendo na primeira coluna a identificacao dos
 #'  testemunhas (tratamentos comuns deve ter valor zero ou NA). A segunda coluna
 #'  deve ter a identificacao de todos os tratamentos.  A terceira coluna a
@@ -23,6 +23,14 @@
 #'@param  alfa valor indicando o nivel de significancia deve ser
 #'  obrigatoriamente "0.001", "0.01", "0.05" ou "0.10" (default = 0.05).
 #'@param  verbose Valor logico (TRUE/FALSE). TRUE apresenta os resultados da analise.
+#'@param  plot Valor numerico indicando o grafico desejado para analise dos residuos:
+#'   \itemize{
+#'    \item 1: Residuals vs Fitted
+#'   \item 2:  QQ-plot
+#'    \item 3:  Scale-Location
+#'     \item 4:  Cook's distance
+#'      \item 5: Histogram
+#'      }
 #'@return Retorna a comparacao multipla de medias obtida por varios testes.
 #' @author Alcinei Mistico Azevedo, \email{alcineimistico@@hotmail.com}
 #'@references
@@ -44,7 +52,8 @@
 #' data(Dados2)
 #' dbc.ad(Dados = Dados2,alfa = 0.05,quali =FALSE)
 #'@export
-dbc.ad=function (Dados, alfa=0.05,quali=TRUE,verbose=TRUE){
+dbc.ad=function (Dados, alfa=0.05,quali=TRUE,verbose=TRUE,plot=2){
+  pp=plot
   Dados[,1]=as.character(Dados[,1])
   Dados[is.na(Dados[,1]),1]=0
   Dados[,2]=as.character(Dados[,2])
@@ -124,6 +133,25 @@ dbc.ad=function (Dados, alfa=0.05,quali=TRUE,verbose=TRUE){
        CV=100 * sqrt(QMR)/mean(DT[, 3])
        if(verbose){print(paste("CV= ",round(CV,4)) )}
 
+       TT=paste(Dados[,1],Dados[,2])
+       m=aov(Dados[,4]~TT+as.factor(Dados[,3]))
+      if(pp<5){(plot(m,pp))}
+       if(pp==5){(hist(residuals(m)))}
+
+
+      if(verbose){print("")}
+       if(verbose){print("Teste de normalidade")}
+       ST=shapiro.test(residuals(m))
+       if(verbose){print(ST)}
+       BT=bartlett.test(residuals(m),TT)
+       if(verbose){print("")}
+       if(verbose){print("Teste de homogeneidade de variancias")}
+       if(verbose){print(BT)}
+
+
+
+
+
        if(verbose){print("")}
        if(verbose){print("Testes")}
                 if(quali==T){
@@ -214,6 +242,28 @@ dbc.ad=function (Dados, alfa=0.05,quali=TRUE,verbose=TRUE){
                   if(verbose){print(anova)}
                 CV=100 * sqrt(QMR)/mean(DT[, 3])
                 if(verbose){print(paste("CV= ",round(CV,4)) )}
+
+
+                TT=paste(Dados[,1],Dados[,2])
+                m=aov(Dados[,4]~TT+as.factor(Dados[,3]))
+                if(pp<5){(plot(m,pp))}
+                if(pp==5){(hist(residuals(m)))}
+
+
+                if(verbose){print("")}
+                if(verbose){print("Teste de normalidade")}
+                ST=shapiro.test(residuals(m))
+                if(verbose){print(ST)}
+                BT=bartlett.test(residuals(m),TT)
+                if(verbose){print("")}
+                if(verbose){print("Teste de homogeneidade de variancias")}
+                if(verbose){print(BT)}
+
+
+
+
+
+
                   if(verbose){print("")}
                     if(verbose){print("Testes")}
                 if(quali==T){
